from stringlike.core import StringLike


__version__ = '0.3.1'
VERSION = tuple(map(int, __version__.split('.')))

__all__ = ['StringLike']
